@@ -1,6 +1,7 @@
 package DBIx::Skinny::DBD::Pg;
 use strict;
 use warnings;
+use DBIx::Skinny::SQL;
 
 sub last_insert_id {
     my ($self, $dbh, $sth, $args) = @_;
@@ -11,6 +12,9 @@ sub sql_for_unixtime {
     "TRUNC(EXTRACT('epoch' from NOW()))";
 }
 
+sub quote    { '"' }
+sub name_sep { '.' }
+
 sub bulk_insert {
     my ($skinny, $table, $args) = @_;
 
@@ -25,4 +29,6 @@ sub bulk_insert {
     return 1;
 }
 
+sub query_builder_class { 'DBIx::Skinny::SQL' }
+
 1;
