@@ -1,8 +1,11 @@
 package Mock::Inflate::Name;
-use overload '""' => sub { shift->name}, fallback => 1;
 sub new {
     my($class, %args) = @_;
     bless { %args }, $class;
 }
-sub name { shift->{name} };
+sub name {
+    my $self = shift;
+    $self->{name} = shift if @_;
+    $self->{name};
+};
 1;
